@@ -106,7 +106,7 @@ class TwitterObject:
             'tweet.fields': 'attachments,author_id,created_at,entities,geo,id,in_reply_to_user_id,lang,possibly_sensitive,public_metrics,referenced_tweets,reply_settings,source,text,withheld',
             'user.fields': 'created_at,description,entities,id,location,name,pinned_tweet_id,profile_image_url,protected,public_metrics,url,username,verified',
             'max_results': 500,
-            'expansions': 'attachments.poll_ids,conversation_id,attachments.media_keys,author_id,geo.place_id,in_reply_to_user_id,referenced_tweets.id,entities.mentions.username,referenced_tweets.id.author_id',
+            'expansions': 'attachments.poll_ids,attachments.media_keys,author_id,geo.place_id,in_reply_to_user_id,referenced_tweets.id,entities.mentions.username,referenced_tweets.id.author_id',
             'media.fields': 'duration_ms,height,media_key,preview_image_url,public_metrics,type,url,width',
             'start_time': self.start_time,
             'end_time': self.end_time
